# coding: utf-8

"""
    qoery

    The Cheapest DeFi Data API.

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from qoery.models.pools_response import PoolsResponse

class TestPoolsResponse(unittest.TestCase):
    """PoolsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PoolsResponse:
        """Test PoolsResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PoolsResponse`
        """
        model = PoolsResponse()
        if include_optional:
            return PoolsResponse(
                data = [
                    {"id":"0x88e6a0c2ddd26feeb64f039a2c41296fcb3f5640","network":"ethereum","protocolVersion":"uniswap-v3","feeTier":"3000","liquidity":"45000000000000000000","sqrtPrice":"1234567890123456789","volumeUSD":"5000000.50","txCount":"12345","totalValueLockedUSD":"10000000.00","token0":{"symbol":"WETH","name":"Wrapped Ether","address":"0xc02aaa39b223fe8d0a0e5c4f27ead9083c756cc2"},"token1":{"symbol":"USDC","name":"USD Coin","address":"0xa0b86991c6218b36c1d19d4a2e9eb0ce3606eb48"}}
                    ],
                credits_used = 3
            )
        else:
            return PoolsResponse(
        )
        """

    def testPoolsResponse(self):
        """Test PoolsResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
