# coding: utf-8

# flake8: noqa
"""
    qoery

    The Cheapest DeFi Data API.

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from qoery._internal.models.candle import Candle
from qoery._internal.models.candles_response import CandlesResponse
from qoery._internal.models.error import Error
from qoery._internal.models.health_response import HealthResponse
from qoery._internal.models.pool import Pool
from qoery._internal.models.pools_response import PoolsResponse
from qoery._internal.models.tick import Tick
from qoery._internal.models.ticks_response import TicksResponse
from qoery._internal.models.token import Token
from qoery._internal.models.usage_response import UsageResponse
from qoery._internal.models.usage_response_api_calls import UsageResponseApiCalls
from qoery._internal.models.usage_response_api_calls_minute import UsageResponseApiCallsMinute
from qoery._internal.models.usage_response_api_calls_month import UsageResponseApiCallsMonth
from qoery._internal.models.usage_response_credits import UsageResponseCredits
from qoery._internal.models.usage_response_credits_minute import UsageResponseCreditsMinute
from qoery._internal.models.usage_response_credits_month import UsageResponseCreditsMonth
