# coding: utf-8

"""
    qoery

    The Cheapest DeFi Data API.

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from qoery.models.usage_response import UsageResponse

class TestUsageResponse(unittest.TestCase):
    """UsageResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UsageResponse:
        """Test UsageResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UsageResponse`
        """
        model = UsageResponse()
        if include_optional:
            return UsageResponse(
                credits = qoery.models.usage_response_credits.UsageResponse_credits(
                    minute = qoery.models.usage_response_credits_minute.UsageResponse_credits_minute(
                        used = 56, 
                        limit = 56, 
                        remaining = 56, 
                        reset_at = '2023-11-30T12:00Z', ), 
                    month = qoery.models.usage_response_credits_month.UsageResponse_credits_month(
                        used = 56, 
                        limit = 56, 
                        remaining = 56, 
                        billing_period_start = '2023-11-30T12:00Z', ), ),
                api_calls = qoery.models.usage_response_api_calls.UsageResponse_api_calls(
                    minute = qoery.models.usage_response_api_calls_minute.UsageResponse_api_calls_minute(
                        used = 56, ), 
                    month = qoery.models.usage_response_api_calls_month.UsageResponse_api_calls_month(
                        used = 56, ), ),
                subscription_plan = 'free'
            )
        else:
            return UsageResponse(
        )
        """

    def testUsageResponse(self):
        """Test UsageResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
