# coding: utf-8

"""
    qoery

    The Cheapest DeFi Data API.

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from qoery.models.pool import Pool

class TestPool(unittest.TestCase):
    """Pool unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Pool:
        """Test Pool
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Pool`
        """
        model = Pool()
        if include_optional:
            return Pool(
                id = '',
                network = 'ethereum',
                protocol_version = 'uniswap-v3',
                fee_tier = '3000',
                liquidity = '',
                sqrt_price = '',
                volume_usd = '',
                tx_count = '',
                total_value_locked_usd = '',
                token0 = qoery.models.token.Token(
                    symbol = 'WETH', 
                    name = 'Wrapped Ether', 
                    address = '0xc02aaa39b223fe8d0a0e5c4f27ead9083c756cc2', 
                    decimals = 18, ),
                token1 = qoery.models.token.Token(
                    symbol = 'WETH', 
                    name = 'Wrapped Ether', 
                    address = '0xc02aaa39b223fe8d0a0e5c4f27ead9083c756cc2', 
                    decimals = 18, )
            )
        else:
            return Pool(
        )
        """

    def testPool(self):
        """Test Pool"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
