# coding: utf-8

"""
    qoery

    The Cheapest DeFi Data API.

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from qoery.models.candle import Candle

class TestCandle(unittest.TestCase):
    """Candle unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Candle:
        """Test Candle
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Candle`
        """
        model = Candle()
        if include_optional:
            return Candle(
                time = '2023-11-30T12:00Z',
                open = 1.337,
                high = 1.337,
                low = 1.337,
                close = 1.337,
                volume = 1.337
            )
        else:
            return Candle(
        )
        """

    def testCandle(self):
        """Test Candle"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
