# coding: utf-8

# flake8: noqa

"""
    qoery

    The Cheapest DeFi Data API.

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.0.0"

# Define package exports
__all__ = [
    "AccountApi",
    "DiscoveryApi",
    "MarketDataApi",
    "SystemApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "Candle",
    "CandlesResponse",
    "Error",
    "HealthResponse",
    "Pool",
    "PoolsResponse",
    "Tick",
    "TicksResponse",
    "Token",
    "UsageResponse",
    "UsageResponseApiCalls",
    "UsageResponseApiCallsMinute",
    "UsageResponseApiCallsMonth",
    "UsageResponseCredits",
    "UsageResponseCreditsMinute",
    "UsageResponseCreditsMonth",
]

# import apis into sdk package
from .api.account_api import AccountApi as AccountApi
from .api.discovery_api import DiscoveryApi as DiscoveryApi
from .api.market_data_api import MarketDataApi as MarketDataApi
from .api.system_api import SystemApi as SystemApi

# import ApiClient
from .api_response import ApiResponse as ApiResponse
from .api_client import ApiClient as ApiClient
from .configuration import Configuration as Configuration
from .exceptions import OpenApiException as OpenApiException
from .exceptions import ApiTypeError as ApiTypeError
from .exceptions import ApiValueError as ApiValueError
from .exceptions import ApiKeyError as ApiKeyError
from .exceptions import ApiAttributeError as ApiAttributeError
from .exceptions import ApiException as ApiException

# import models into sdk package
from .models.candle import Candle as Candle
from .models.candles_response import CandlesResponse as CandlesResponse
from .models.error import Error as Error
from .models.health_response import HealthResponse as HealthResponse
from .models.pool import Pool as Pool
from .models.pools_response import PoolsResponse as PoolsResponse
from .models.tick import Tick as Tick
from .models.ticks_response import TicksResponse as TicksResponse
from .models.token import Token as Token
from .models.usage_response import UsageResponse as UsageResponse
from .models.usage_response_api_calls import UsageResponseApiCalls as UsageResponseApiCalls
from .models.usage_response_api_calls_minute import UsageResponseApiCallsMinute as UsageResponseApiCallsMinute
from .models.usage_response_api_calls_month import UsageResponseApiCallsMonth as UsageResponseApiCallsMonth
from .models.usage_response_credits import UsageResponseCredits as UsageResponseCredits
from .models.usage_response_credits_minute import UsageResponseCreditsMinute as UsageResponseCreditsMinute
from .models.usage_response_credits_month import UsageResponseCreditsMonth as UsageResponseCreditsMonth
