# coding: utf-8

"""
    qoery

    The Cheapest DeFi Data API.

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from qoery.models.ticks_response import TicksResponse

class TestTicksResponse(unittest.TestCase):
    """TicksResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TicksResponse:
        """Test TicksResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TicksResponse`
        """
        model = TicksResponse()
        if include_optional:
            return TicksResponse(
                data = [
                    qoery.models.tick.Tick(
                        id = '', 
                        timestamp = '2023-11-30T12:00Z', 
                        price = 1.337, 
                        side = 'buy', 
                        amount0 = '', 
                        amount1 = '', 
                        amount_usd = 1.337, 
                        sqrt_price_x96 = '', 
                        token0 = '', 
                        token1 = '', )
                    ],
                credits_used = 2
            )
        else:
            return TicksResponse(
        )
        """

    def testTicksResponse(self):
        """Test TicksResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
